%define version_major 1
%define version_minor %{version_major}.3

Name:		libQGLViewer
Version:	%{version_minor}.4
Release:	1mdk

Summary:	OpenGL 3D viewer library based on Qt
License:	GPL
Group:		System/Libraries
Source:		%{name}-%{version}.tar.bz2
URL:		http://www-imagis.imag.fr/Membres/Gilles.Debunne/CODE/QGLViewer
Buildroot:      %{_tmppath}/%{name}-%{version}-buildroot

%description
A versatile 3D viewer library for 3D application development.
Features many useful classical functionalities such as a camera trackball,
screenshot savings, stereo display, (hierarchical) frames that can be moved
with the mouse, keyFrame interpolator...

%package devel
Summary: The libQGLViewer header files, documentation and exemples.
Group: System/Libraries
Requires: %{name} = %{version}

%description devel
This package contains the header files for libQGLViewer.
Install this package if you want to develop a program
that uses libQGLViewer. A reference documentation and pedagogical
exemples are included. 

%prep
%define docdir %{_docdir}/QGLViewer
%define headerdir /usr/local/include/QGLViewer
%define libdir /usr/local/lib
%setup
  
%build
cd src
if [[ -z "${QTDIR}" ]]
then
  if [[ -d /usr/lib/qt3 ]]
  then
    export QTDIR=/usr/lib/qt3
  else
    echo "Trying to autodetect QTDIR..."
    autoDetect=`locate lib/libqt-mt.so.3 | head -1 | sed s:"\(\)/lib/libqt-mt.so.3":"\1":`
    if [[ -d $autoDetect ]]
    then
      export QTDIR=$autoDetect
    else
      echo "--- Compilation error : QTDIR is undefined, unable to run qmake"
      echo "--- Use export QTDIR=... ([ba]sh) or setenv QTDIR ... ([t]csh) and re-run."
      exit 1
    fi
  fi
fi

export PATH=${PATH}:${QTDIR}/bin
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${QTDIR}/lib
qmake
make

%install
rm -rf $RPM_BUILD_ROOT
%{__install} -d $RPM_BUILD_ROOT%{headerdir}
%{__install} --mode=644 src/*.h $RPM_BUILD_ROOT%{headerdir}
%{__install} -d $RPM_BUILD_ROOT%{headerdir}/cwFiles
%{__install} --mode=644 src/cwFiles/*.cw $RPM_BUILD_ROOT%{headerdir}/cwFiles
%{__install} --mode=644 src/cwFiles/*.png $RPM_BUILD_ROOT%{headerdir}/cwFiles

%{__install} -d $RPM_BUILD_ROOT%{libdir}
%{__install} --mode=644 src/libQGLViewer.so.%{version} $RPM_BUILD_ROOT%{libdir}
ln -s libQGLViewer.so.%{version} $RPM_BUILD_ROOT%{libdir}/libQGLViewer.so.%{version_minor}
ln -s libQGLViewer.so.%{version} $RPM_BUILD_ROOT%{libdir}/libQGLViewer.so.%{version_major}
ln -s libQGLViewer.so.%{version} $RPM_BUILD_ROOT%{libdir}/libQGLViewer.so

# %{__install} -d $RPM_BUILD_ROOT%{_mandir}/man3
%{__install} -d $RPM_BUILD_ROOT%{docdir}
%{__install} -d $RPM_BUILD_ROOT%{docdir}/refManual
%{__install} -d $RPM_BUILD_ROOT%{docdir}/images
%{__install} -d $RPM_BUILD_ROOT%{docdir}/examples
# %{__install} doc/man/man3/QGLViewer.3 $RPM_BUILD_ROOT%{_mandir}/man3/
# %{__install} doc/man/man3/qglviewer_* $RPM_BUILD_ROOT%{_mandir}/man3/
%{__install} --mode=644 doc/*.html doc/*.css $RPM_BUILD_ROOT%{docdir}
%{__install} --mode=644 INSTALL README LICENCE CHANGELOG $RPM_BUILD_ROOT%{docdir}
%{__install} --mode=644 doc/refManual/* $RPM_BUILD_ROOT%{docdir}/refManual
%{__install} --mode=644 doc/images/* $RPM_BUILD_ROOT%{docdir}/images
%{__install} --mode=644 doc/examples/*.html $RPM_BUILD_ROOT%{docdir}/examples
%{__install} --mode=644 examples/*.pro $RPM_BUILD_ROOT%{docdir}/examples
for dir in `ls examples`
do
if [[ -d examples/$dir ]]
  then
    %{__install} -d $RPM_BUILD_ROOT%{docdir}/examples/$dir
    %{__install} --mode=644 examples/$dir/* $RPM_BUILD_ROOT%{docdir}/examples/$dir
  fi
done

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{libdir}/%{name}.so
%{libdir}/%{name}.so.%{version_minor}
%{libdir}/%{name}.so.%{version_major}
%{libdir}/%{name}.so.%{version}


%files devel
%defattr(-,root,root)
%dir %{headerdir}
%{headerdir}/*.h
%dir %{headerdir}/cwFiles
%{headerdir}/cwFiles/*.cw
%{headerdir}/cwFiles/*.png

# %doc %{_mandir}/man3/QGLViewer.3.bz2
# %doc %{_mandir}/man3/qglviewer_*

%dir %{docdir}
%doc %{docdir}/*.html
%doc %{docdir}/*.css
%doc %{docdir}/README
%doc %{docdir}/LICENCE
%doc %{docdir}/INSTALL
%doc %{docdir}/CHANGELOG
%dir %{docdir}/refManual
%doc %{docdir}/refManual/*
%dir %{docdir}/images
%doc %{docdir}/images/*
%dir %{docdir}/examples
# %doc %{docdir}/examples/*.html
# %doc %{docdir}/examples/*.pro
%dir %{docdir}/examples/*
%doc %{docdir}/examples/*/*

%changelog
* Wed Jul 23 2003 Lenny Cartier <lenny@mandrakesoft.com> 1.3.4-1mdk
- from Gilles Debunne <Gilles.Debunne@imag.fr> : 
	- Mouse bindings configuration

* Wed Jun 25 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.3.3-1
- Doxygen search engine, FAQ page, Z-buffer display, constraints in KFI.

* Mon May 5 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.3.2-2
- /usr/lib changed to /usr/local/lib

* Thu Apr 17 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.3.2-1
- help() uses popup windows. DLL created for windows.

* Wed Apr 10 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.3.1-1
- A ManipulatedCameraFrame class. double in Quaternion.

* Wed Mar 26 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.3.0-1
- Many changes in the API. Documentation updated. A new MouseGrabber class.

* Wed Mar 19 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.9-3
- ORTHO camera improvements, better default help().

* Wed Mar 5 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.9-2
- Slerp interpolation fixed. Tiny Camera matrix improvements.

* Wed Feb 26 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.9-1
- No more camera referenceFrame, slerp interpolation and new install paths.

* Wed Jan 29 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.8-3
- pixelGLRatio function, minor changes.

* Wed Jan 22 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.8-2
- Minor bug fixes. GL state saving optimized.

* Wed Jan 15 2003 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.8-1
- SPECIAL key disappears. New trackball features.

* Thu Dec 12 2002 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.7-2
- Minor improvements, draw3DText. Mac and Windows compatible release.
- Documentation and examples added to the distribution.

* Wed Dec 4 2002 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.7-1
- KeyFrameInterpolator and EPSRender. Bug fixes and new trackball

* Thu Sep 10 2002 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.6-1
- New features and bug fixes. See CHANGELOG for details. Cleaner spec.

* Thu Jul 25 2002 Xavier Decoret <Xavier.Decoret@imag.fr> 1.2.5-2
- Links with qt-mt (multithread) so it works fine with Mandrake libqt3-devel
- fix the spec file: files were copied in /usr directories during rebuild!

* Tue Jul 16 2002 Gilles Debunne <Gilles.Debunne@imag.fr> 1.2.5-1
- First rpm release
